@@ -1,8 +1,11 @@
 from .client import SyncClient, AsyncClient
 from .city import City
 from .enums import HistoryMode
+from .range import Range
+from .siren import Siren
+from .utils import create_map_url_from_cities
 
 __title__ = "pikudhaoref"
-__version__ = "0.0.4"
+__version__ = "0.0.8"
 __author__ = "adam7100"
 __license__ = "MIT"
