@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from enum import Enum
 
-__all__ = ("HistoryMode",)
+__all__ = ("HistoryMode", "MatchMode")
 
 
 class HistoryMode(Enum):
@@ -10,3 +10,8 @@ class HistoryMode(Enum):
     TODAY = 1
     LAST_WEEK = 2
     LAST_MONTH = 3
+
+
+class MatchMode(Enum):
+    EXACT = 0
+    IN = 1
