@@ -4,9 +4,10 @@ from dataclasses import dataclass
 from datetime import datetime
 
 import pytz
-from typing import Dict, List, Any
+from typing import Dict, TYPE_CHECKING, Any
 
-from .city import City
+if TYPE_CHECKING:
+    from .city import City
 
 __all__ = ("Siren",)
 
@@ -17,15 +18,14 @@ class Siren:
     Represents a siren.
     """
 
-    city: City
+    city: City | str
     datetime: datetime
 
     @classmethod
-    def from_raw(cls, raw: Dict[str, str], city_data: List[Dict[str, Any]]) -> Siren:
+    def from_raw(cls, raw: Dict[str, Any]) -> Siren:
         """
         Returns a Siren object from the dictionary.
 
-        :param List[Dict[str, Any]] city_data: The city data to fetch.
         :param Dict[str, str] raw: The raw dictionary.
         :return: The siren object.
         :rtype: Siren
@@ -35,6 +35,6 @@ class Siren:
         date = datetime.strptime(raw["datetime"], "%Y-%m-%dT%H:%M:%S")
 
         return cls(
-            City.from_city_name(raw["data"], city_data),
+            raw["data"],
             israel_timezone.localize(date).astimezone(pytz.utc),
         )
